==> kadu_1.2.orig.tar.bz2: kadu-1.2/plugins/autoaway/translations/autoaway_ru.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="ru" version="2.0">
<context>
    <name>@default</name>
    <message>
        <source>Status</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Check idle every</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Set status to away after</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Set status to invisible after</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Description</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Replace</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>New description</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Set status to extended away after</source>
        <translation type="unfinished"/>
    </message>
    <message numerus="yes">
        <source>%n second(s)</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <source>Do Not Change</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Behavior</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Inactivity</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Refresh status every</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Switch to &apos;away&apos;</source>
        <translation type="unfinished"/>
    </message>
    <message numerus="yes">
        <source>%n minute(s)</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <source>Switch to &apos;auto extended away&apos;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Switch to &apos;invisible&apos;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Switch to &apos;offline&apos;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Set status to offline after</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Status description when inactive</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Prepend</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Append</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>AutoAway</name>
    <message>
        <source>Don&apos;t refresh</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>

==> kadu_3.0.orig.tar.bz2: kadu-3.0/plugins/autoaway/translations/autoaway_ru.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="ru" version="2.1">
<context>
    <name>@default</name>
    <message>
        <source>Status</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Check idle every</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Set status to away after</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Set status to invisible after</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Description</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Replace</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>New description</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Set status to extended away after</source>
        <translation type="unfinished"/>
    </message>
    <message numerus="yes">
        <source>%n second(s)</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <source>Do Not Change</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Behavior</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Inactivity</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Refresh status every</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Switch to &apos;away&apos;</source>
        <translation type="unfinished"/>
    </message>
    <message numerus="yes">
        <source>%n minute(s)</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <source>Switch to &apos;auto extended away&apos;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Switch to &apos;invisible&apos;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Switch to &apos;offline&apos;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Set status to offline after</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Status description when inactive</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Prepend</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Append</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>AutoAway</name>
    <message>
        <source>Don&apos;t refresh</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>
